==> zio-aws-networkfirewall_3-5.17.201.1-sources.jar: zio/aws/networkfirewall/model/PerObjectSyncStatus.scala <==
package zio.aws.networkfirewall.model
import scala.jdk.CollectionConverters.*
sealed trait PerObjectSyncStatus {
  def unwrap: software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus
}
object PerObjectSyncStatus {
  def wrap(
      value: software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus
  ): zio.aws.networkfirewall.model.PerObjectSyncStatus = value match {
    case software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.PENDING =>
      val r = PENDING
      r
    case software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.IN_SYNC =>
      val r = IN_SYNC
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.networkfirewall.model.PerObjectSyncStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus =
      software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object PENDING
      extends zio.aws.networkfirewall.model.PerObjectSyncStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus =
      software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.PENDING
  }
  case object IN_SYNC
      extends zio.aws.networkfirewall.model.PerObjectSyncStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus =
      software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.IN_SYNC
  }
}

==> zio-aws-networkfirewall_3-5.19.7.5-sources.jar: zio/aws/networkfirewall/model/PerObjectSyncStatus.scala <==
package zio.aws.networkfirewall.model
import scala.jdk.CollectionConverters.*
sealed trait PerObjectSyncStatus {
  def unwrap: software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus
}
object PerObjectSyncStatus {
  def wrap(
      value: software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus
  ): zio.aws.networkfirewall.model.PerObjectSyncStatus = value match {
    case software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.PENDING =>
      val r = PENDING
      r
    case software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.IN_SYNC =>
      val r = IN_SYNC
      r
    case software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.CAPACITY_CONSTRAINED =>
      val r = CAPACITY_CONSTRAINED
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.networkfirewall.model.PerObjectSyncStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus =
      software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object PENDING
      extends zio.aws.networkfirewall.model.PerObjectSyncStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus =
      software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.PENDING
  }
  case object IN_SYNC
      extends zio.aws.networkfirewall.model.PerObjectSyncStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus =
      software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.IN_SYNC
  }
  case object CAPACITY_CONSTRAINED
      extends zio.aws.networkfirewall.model.PerObjectSyncStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus =
      software.amazon.awssdk.services.networkfirewall.model.PerObjectSyncStatus.CAPACITY_CONSTRAINED
  }
}
